@@ -8,7 +8,7 @@
 #
 from detector_connector import DetectorConnector, DetectorAnalyzeResult
 
-from pollution_detector_connector.pollution_setting import PollutionSetting
+from pollution_detector_connector.pollution_settings import PollutionSettings
 
 
 class PollutionDetectorConnector(DetectorConnector):
@@ -20,5 +20,5 @@ class PollutionDetectorConnector(DetectorConnector):
             config=config,
             context=context,
             detector_analyze_result_type=DetectorAnalyzeResult,
-            detector_settings_type=PollutionSetting,
+            detector_settings_type=PollutionSettings,
         )
